==> benno-web-2.4.1.tgz: srv/benno/bennoweb/htdocs/pre_ctrl.php <==
<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */

/** $Id: $
 *
 * Copyright (c) 2005 Martin Werthmoeller <mw@lw-systems.de>
 *
 */
/**
 * @package pre_ctrl
 */
/**
 * 
 * pre_ctrl.php will called before the ctrl component.
 *
 */

$search_limit = $App->getSession('search_limit');
if (!$search_limit) {
    $search_limit = $App->getConfig('DEFAULT_LIMIT');
}

$EMail       = $App->getSession('EMail');
$QueryResult = $App->getSession('QueryResult');
$Backend     = $App->getSession('Backend');
// current archive
$archive     = $App->getSession('archive');

// fetch query field entries from session
$searchmin   = $App->getSession('searchmin');
$SimpleQuery = $App->getSession('SimpleQuery');
$ExtQuery    = $App->getSession('ExtQuery');
$QueryList   = $App->getSession('QueryList');
$FilterList  = $App->getSession('FilterList');

// default search $timeslice days
$timeslice = $App->getSession('timeslice');

// sort messages (dateAsc dateDesc)
$sortOrder = $App->getSession('sortOrder');

// last mail shown
$sessionMailId = $App->getSession('sessionMailId');

// refresh last request time (session timeout)
$lastRequestTime = $App->getSession('lastRequestTime'); // view/a_sessionRefresh
$App->setSession('lastRequestTime',time());

$Audit = new Audit();


?>

==> benno-web-2.6.4.tgz: srv/benno/bennoweb/htdocs/pre_ctrl.php <==
<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */

/** $Id: $
 *
 * Copyright (c) 2005 Martin Werthmoeller <mw@lw-systems.de>
 *
 */
/**
 * @package pre_ctrl
 */
/**
 * 
 * pre_ctrl.php will called before the ctrl component.
 *
 */

$search_limit = $App->getSession('search_limit');
if (!$search_limit) {
    $search_limit = $App->getConfig('DEFAULT_LIMIT','25');
}

$EMail       = $App->getSession('EMail');
$QueryResult = $App->getSession('QueryResult');
$Backend     = $App->getSession('Backend');
// current archive
$archive     = $App->getSession('archive');

// fetch query field entries from session
$searchmin   = $App->getSession('searchmin');
$SimpleQuery = $App->getSession('SimpleQuery');
$ExtQuery    = $App->getSession('ExtQuery');
$QueryList   = $App->getSession('QueryList');
$FilterList  = $App->getSession('FilterList');

// default search $timeslice days
$timeslice = $App->getSession('timeslice');

// sort messages (dateAsc dateDesc)
$sortOrder = $App->getSession('sortOrder');

// last mail shown
$sessionMailId = $App->getSession('sessionMailId');

// refresh last request time (session timeout)
$lastRequestTime = $App->getSession('lastRequestTime'); // view/a_sessionRefresh
$App->setSession('lastRequestTime',time());

$Audit = new Audit();


?>
